Description Usage Arguments Value References Examples
The function converts raw community data to hypergeometric probabilities from a random draw of NESSm individuals followed by station normalization. The CNESS distance can then be obtained by computing the Euclidean distance on the transformed data (see Trueblood et al., 1994; Gallagher 1996).
1 | CNESS(X, m)
|
X |
Community data matrix, samples as rows, species as column |
m |
NESSm value, can range from 1 (high weight to adundant species) to the minimum sample total (high weight to rare species). The NESSm function compute the best trade-off. |
Standardized data frame
Gallagher, E.D., 1996. COMPAH documentation. 65 p. http://citeseerx.ist.psu.edu/viewdoc/download?doi=10.1.1.9.1334&rep=rep1&type=pdf. Trueblood, D.D., Gallagher, E.D., Gould, D.M., 1994. Three stages of seasonal succession on the Savin Hill Cove mudflat, Boston Harbor. Limnology and Oceanography 39, 1440-1454.
1 2 3 4 5 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.