NESSm: NESSm sample size

Description Usage Arguments Value References Examples

Description

Computes the sample size that provides the best trade-off between NESSm = 1 (giving high weight to abundant species) and NESSm= "minimum sample total" (giving high weight to rare species), after Trueblood et al. (1994) and Gallagher (1996).

Usage

1
NESSm(X)

Arguments

X

Community data matrix, samples as rows, species as column

Value

sample size to be used in CNESS or NNESS to produce an index sensitive to both rare and abundant species

References

Gallagher, E.D., 1996. COMPAH documentation. 65 p. http://citeseerx.ist.psu.edu/viewdoc/download?doi=10.1.1.9.1334&rep=rep1&type=pdf. Trueblood, D.D., Gallagher, E.D., Gould, D.M., 1994. Three stages of seasonal succession on the Savin Hill Cove mudflat, Boston Harbor. Limnology and Oceanography 39, 1440-1454.

Examples

1
2
3
4
5
6
7
require(vegan)
data(varespec)
m <- NESSm(varespec) # Be patient, computation is slow

### Note that the function doesn't work with large numbers nor data matrix with no variance
largenumber <- matrix(rnorm(100, 1000, 100), 10 , 10)
m <- NESSm(largenumber)

Lenaick-Menot/ness documentation built on June 25, 2019, 12:05 a.m.