NNESS: New Normalized Expected Specis Shared (NNESS)

Description Usage Arguments Value References

Description

This functions computes the NNESS similarity index from a random draw of NESSm individuals (see Gallagher, 1996).

Usage

1
NNESS(X, m)

Arguments

X

Community data matrix, samples as rows, species as column

m

NESSm value, can range from 1 (high weight to adundant species) to the minimum sample total (high weight to rare species). The NESSm function compute the best trade-off.

Value

distance object, the similarity matrix between samples

@examples library(vegan) data(varespec) m <- NESSm(varespec) nness.dist <- NNESS(varespec, m)

References

Gallagher, E.D., 1996. COMPAH documentation. 65 p. http://citeseerx.ist.psu.edu/viewdoc/download?doi=10.1.1.9.1334&rep=rep1&type=pdf.


Lenaick-Menot/ness documentation built on June 25, 2019, 12:05 a.m.